summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorcadmic <cadmic24@gmail.com>2025-01-10 09:47:55 -0800
committerGitHub <noreply@github.com>2025-01-10 18:47:55 +0100
commite4ad4e5eeefd27fe67b7f29fbac884a7d8a986d2 (patch)
tree20579a049afeedd10a8a74f7e333798fa90c0835 /include
parent26f91bd3bb51bcac0dc06f21f345beedfe663bcb (diff)
[iQue] Match remaining src/boot files (#2417)
* [iQue] Match remaining src/boot files * Fix debug ROM * Use -funsigned-char * Sort ique before gc in LNx macros
Diffstat (limited to 'include')
-rw-r--r--include/functions.h3
-rw-r--r--include/line_numbers.h16
2 files changed, 8 insertions, 11 deletions
diff --git a/include/functions.h b/include/functions.h
index 092616bce..f89ce3a0a 100644
--- a/include/functions.h
+++ b/include/functions.h
@@ -9,9 +9,6 @@ void Main_ThreadEntry(void* arg);
void Idle_ThreadEntry(void* arg);
void ViConfig_UpdateVi(u32 black);
void ViConfig_UpdateBlack(void);
-void* Yaz0_FirstDMA(void);
-void* Yaz0_NextDMA(u8* curSrcPos);
-void Yaz0_DecompressImpl(u8* src, u8* dst);
#if !PLATFORM_IQUE
void Yaz0_Decompress(uintptr_t romStart, u8* dst, size_t size);
#else
diff --git a/include/line_numbers.h b/include/line_numbers.h
index f0d0ae5fa..bc11d555d 100644
--- a/include/line_numbers.h
+++ b/include/line_numbers.h
@@ -52,16 +52,16 @@
#define LN2(ntsc_1_0, ntsc_1_1, other) \
LN(ntsc_1_0, ntsc_1_1, other, other, other, other, other, other, other, other, other, other, other, other)
-// NTSC 1.0, Gamecube, and all the other versions
-#define LN3(ntsc_1_0, other, gc) \
- LN(ntsc_1_0, other, other, other, other, gc, gc, gc, gc, gc, gc, gc, gc, gc)
+// NTSC 1.0, iQue, GameCube, and all the other versions
+#define LN3(ntsc_1_0, other, ique, gc) \
+ LN(ntsc_1_0, other, other, other, other, gc, gc, gc, gc, gc, gc, gc, gc, ique)
-// NTSC 1.0, NTSC 1.1, Gamecube, and all the other versions
-#define LN4(ntsc_1_0, ntsc_1_1, other, gc, ique) \
+// NTSC 1.0, NTSC 1.1, iQue, GameCube, and all the other versions
+#define LN4(ntsc_1_0, ntsc_1_1, other, ique, gc) \
LN(ntsc_1_0, ntsc_1_1, other, other, other, gc, gc, gc, gc, gc, gc, gc, gc, ique)
-// NTSC 1.0, NTSC 1.1, NTSC 1.2/PAL 1.0, Gamecube US/JP, Gamecube EU, and Gamecube CE
-#define LN5(ntsc_1_0, ntsc_1_1, other, pal_1_1, gc_ntsc, gc_eu, gc_jp_ce) \
- LN(ntsc_1_0, ntsc_1_1, other, other, pal_1_1, gc_ntsc, gc_ntsc, gc_ntsc, gc_ntsc, gc_eu, gc_eu, gc_eu, gc_jp_ce, gc_jp_ce)
+// NTSC 1.0, NTSC 1.1, NTSC 1.2/PAL 1.0, iQue, Gamecube US/JP, Gamecube EU, and Gamecube CE
+#define LN5(ntsc_1_0, ntsc_1_1, other, pal_1_1, ique, gc_ntsc, gc_eu, gc_jp_ce) \
+ LN(ntsc_1_0, ntsc_1_1, other, other, pal_1_1, gc_ntsc, gc_ntsc, gc_ntsc, gc_ntsc, gc_eu, gc_eu, gc_eu, gc_jp_ce, ique)
#endif